@@ -114,40 +114,79 @@ windmill.controller.asserts.assertRegistry = {
 //Currently only does one level below the provided div
 //To make it more thorough it needs recursion to be implemented later
 windmill.controller.asserts.assertText = function (paramObject) {
-
-  var n = lookupNode(paramObject);
+  var n = lookupNode(paramObject, false);
   var validator = paramObject.validator;
-  if (n.innerHTML.indexOf(validator) != -1){
+    
+  var inner = n.innerHTML;
+  if (n.textContent){
+    inner = n.textContent;
+  }
+  else if (n.innerText) {
+    inner = n.innerText;
+  }
+  // new lines and spaces break a lot of these, so removing them makes sense
+  var iHTML = inner.replace(/^\s*|\s*$/g,'');
+  
+  if (iHTML == validator){
     return true;
   }
-  if (n.hasChildNodes()){
-    for(var m = n.firstChild; m != null; m = m.nextSibling) {
-      //for non text nodes
-      if (m.nodeType != 3){
-        if (m.innerHTML.indexOf(validator) != -1){
-          return true;
-        }
-        if (m.value && m.value.indexOf(validator) != -1){
-          return true;
-        }
-      }
-    }
-  }
-  var found = n.textContent;
-  if (found == undefined)
-    found = n.innerText;
+  
+  // var found = n.textContent;
+  // if (found == undefined)
+  //   found = n.innerText;
   throw "Text '" + validator +
-        "' was not found in the provided node.  Found instead: " + found;
+        "' was not found in the provided node.  Found instead: " + iHTML;
 };
 
+windmill.controller.asserts.assertTextIn = function (paramObject) {
+  var n = lookupNode(paramObject, false);
+  var validator = paramObject.validator;
+  
+  var inner = n.innerHTML;
+  if (n.textContent){
+    inner = n.textContent;
+  }
+  else if (n.innerText){
+    inner = n.innerText;
+  }
+  
+  // new lines and spaces break a lot of these, so removing them makes sense
+  var iHTML = inner.replace(/^\s*|\s*$/g,'');
+  
+  if (iHTML.indexOf(validator) != -1){
+    return true;
+  }
+  
+  // var found = n.textContent;
+  // if (found == undefined)
+  //   found = n.innerText;
+  throw "Text '" + validator +
+        "' was not found in the provided node.  Found instead: " + inner;
+};
+
+
 //Assert that a specified node exists
 windmill.controller.asserts.assertNode = function (paramObject) {
-  var element = lookupNode(paramObject);
+  var element = lookupNode(paramObject, false);
 };
 
 //Assert that a form element contains the expected value
 windmill.controller.asserts.assertValue = function (paramObject) {
-  var n = lookupNode(paramObject);
+  //need to start moving test to use text instead of validator, its dumb
+  var n = lookupNode(paramObject, false);
+  var validator = paramObject.validator;
+
+  if (n.value == undefined)
+    throw "Element doesn't have a value";
+
+  if (n.value != validator){
+    throw "Found value \""+ n.value + "\" is not equal to \""+ validator+"\"";
+  }
+};
+
+windmill.controller.asserts.assertValueIn = function (paramObject) {
+  //need to start moving test to use text instead of validator, its dumb
+  var n = lookupNode(paramObject, false);
   var validator = paramObject.validator;
 
   if (n.value == undefined)
@@ -156,7 +195,6 @@ windmill.controller.asserts.assertValue = function (paramObject) {
   if (n.value.indexOf(validator) == -1){
     throw "Found value \""+ n.value + "\" is not equal to \""+ validator+"\"";
   }
-  
 };
 
 //Assert that a provided value is selected in a select element
@@ -179,7 +217,7 @@ windmill.controller.asserts.assertIDEJS = function (paramObject) {
 
 //Asserting javascript with an element object available
 windmill.controller.asserts.assertElemJS = function (paramObject) {
-  var element = lookupNode(paramObject);
+  var element = lookupNode(paramObject, false);
   var js = paramObject.js;
   var result = eval(js);
   if (result != true){
@@ -189,7 +227,7 @@ windmill.controller.asserts.assertElemJS = function (paramObject) {
 
 //Assert that a provided value is selected in a select element
 windmill.controller.asserts.assertSelected = function (paramObject) {
-  var n = lookupNode(paramObject);
+  var n = lookupNode(paramObject, false);
   var validator = paramObject.validator;
 
   if ((n.options[n.selectedIndex].value != validator) && (n.options[n.selectedIndex].innerHTML != validator)){
@@ -199,7 +237,7 @@ windmill.controller.asserts.assertSelected = function (paramObject) {
 
 //Assert that a provided checkbox is checked
 windmill.controller.asserts.assertChecked = function (paramObject) {
-  var n = lookupNode(paramObject);
+  var n = lookupNode(paramObject, false);
 
   if (!n.checked){
     throw "Checked property not true";
@@ -208,7 +246,7 @@ windmill.controller.asserts.assertChecked = function (paramObject) {
 
 // Assert that a an element's property is a particular value
 windmill.controller.asserts.assertProperty = function (paramObject) {
-  var element = lookupNode(paramObject);
+  var element = lookupNode(paramObject, false);
   var vArray = paramObject.validator.split('|');
   if (vArray.length != 2)
     throw "Invalid validator '" + paramObject.validator + "'.  Use '|' to separate key from value.";
@@ -232,7 +270,7 @@ windmill.controller.asserts.assertProperty = function (paramObject) {
 // The Safari workaround results in additional requests
 // for broken images (in Safari only) but works reliably
 windmill.controller.asserts.assertImageLoaded = function (paramObject) {
-  var img = lookupNode(paramObject);
+  var img = lookupNode(paramObject, false);
   if (!img || img.tagName != 'IMG') {
     throw "The node was not an image."
   }
